/**
 * Copyright (c) 2013, mini2Dx Project
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 * Neither the name of the mini2Dx nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.mini2Dx.context;

import java.io.IOException;
import java.util.List;

import org.mini2Dx.injection.annotation.Prototype;
import org.mini2Dx.injection.annotation.Singleton;

/**
 * A common interface to component scanning implementations.
 * 
 * Scans packages for classes annotated with {@link Singleton} and
 * {@link Prototype}
 * 
 * @author Thomas Cashman
 */
public interface ComponentScanner {
	/**
	 * Scans multiple packages recursively for {@link Singleton} and {@link Prototype}
	 * annotated classes
	 * 
	 * @param packageNames  The package name to scan through, e.g. org.mini2Dx.component
	 * @throws IOException
	 */
	public void scan(String[] packageNames) throws IOException, NullPointerException, ClassNotFoundException;

	public List<Class<?>> getSingletonClasses();

	public List<Class<?>> getPrototypeClasses();
}
